README
######

mads package:

 * bots		- several bots available
 * errors	- list of exceptions
 * getters	- object getter functions
 * join		- join lists into strings
 * log		- enable logging
 * name		- extract different names from type()
 * rest		- provide a REST server
 * rss		- allows for RSS feeds to be polled
 * selector	- function to select objects with
 * signature	- verify file signatures
 * templates	- config default templates
 * trace 	- stack trace related
 * url		- helpers for url manipulation
 * clock	- repeater, timers
 * file		- file related
 * json		- custom dumps function
 * misc		- dump file for the "nowhereelse" functions
 * resolve	- host resolving
 * result	- result bot
 * shell	- shell functions
 * storage	- interface to JSON file backend
 * time		- time related helper functions
 * udp		- udp services from the GOZERBOT days
 
mods package:
 
 * aliases	- alias command
 * edit		- edit command
 * entry	- entry commands
 * mbox		- scan emails
 * output	- various output commands
 * proces	- proces commands
 * query	- query/questions
 * reboot	- restart commands
 * silent 	- put bot into silent/loud mode
 * status	- status commands
 * storage	- scan storage backend
 * test		- test comands
 * timer	- what kind of egg you are putting on
 * users	- users related commands
 
email:
 
 * Bart Thate 
 * IRC: botfather on #dunkbots irc.freenode.net
 * email: bthate@dds.nl, thatebart@gmail.com
 
